#
# spec file for package snappy
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lib_name libsnappy1
Name:           snappy
Version:        1.1.3
Release:        3.5
Summary:        A fast compressor/decompressor library
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            https://github.com/google/snappy/
Source0:        https://github.com/google/snappy/archive/%{version}.tar.gz
Source99:       baselibs.conf
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  lzo-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Snappy is a compression/decompression library. It does not aim for maximum
compression, or compatibility with any other compression library; instead, it
aims for very high speeds and reasonable compression. For instance, compared to
the fastest mode of zlib, Snappy is an order of magnitude faster for most
inputs, but the resulting compressed files are anywhere from 20% to 100%
bigger. On a single core of a Core i7 processor in 64-bit mode, Snappy
compresses at about 250 MB/sec or more and decompresses at about
500 MB/sec or more.

%package -n %{lib_name}
Summary:        Shared library from snappy
Group:          Development/Libraries/C and C++

%description -n %{lib_name}
Snappy is a compression/decompression library. It does not aim for maximum compression,
or compatibility with any other compression library; instead, it aims for very high
speeds and reasonable compression. For instance, compared to the fastest mode of zlib,
Snappy is an order of magnitude faster for most inputs, but the resulting compressed
files are anywhere from 20% to 100% bigger. On a single core of a Core i7 processor
in 64-bit mode, Snappy compresses at about 250 MB/sec or more and decompresses at about
500 MB/sec or more.

This package holds the shared library of snappy.

%package devel
Summary:        Development files for snappy
Group:          Development/Libraries/C and C++
Requires:       %{lib_name} = %{version}

%description devel
Snappy is a compression/decompression library. It does not aim for maximum
compression, or compatibility with any other compression library; instead, it
aims for very high speeds and reasonable compression. For instance, compared to
the fastest mode of zlib, Snappy is an order of magnitude faster for most
inputs, but the resulting compressed files are anywhere from 20% to 100%
bigger. On a single core of a Core i7 processor in 64-bit mode, Snappy
compresses at about 250 MB/sec or more and decompresses at about
500 MB/sec or more.

This package holds the development files for snappy.

%prep
%setup -q

%build
autoreconf -fvi
# mvyskocil: disable assertions to improve a speed a bit in microbenchmarks and hopefully in real-world use as well
# http://code.google.com/p/snappy/issues/detail?id=40
%configure CXXFLAGS="%{optflags} -DNDEBUG" \
    --with-pic \
    --disable-static \
    --docdir=%{_defaultdocdir}/%{name}

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -type f -name "*.la" -delete -print
rm %{buildroot}/%{_defaultdocdir}/%{name}/INSTALL

%check
make %{?_smp_mflags} check

%post   -n %{lib_name} -p /sbin/ldconfig

%postun -n %{lib_name} -p /sbin/ldconfig

%files -n %{lib_name}
%defattr(-,root,root,-)
%doc %{_defaultdocdir}/%{name}/COPYING
%{_libdir}/libsnappy.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/snappy*.h
%{_libdir}/libsnappy.so
%doc %{_defaultdocdir}/%{name}
%exclude %{_defaultdocdir}/%{name}/COPYING

%changelog
* Wed Jul 29 2015 tchvatal@suse.com
- Version bump to 1.1.3:
  * See the NEWS file for full details
- Switch to distribution from github
- Remove upstreamed patch:
  * snappy-1.1.1-random-return.patch
* Wed Jul 29 2015 dimstar@opensuse.org
- Add baselibs.conf: build snappy1-32bit, as needed by
  libqt5-qtwebengine-32bit.
* Thu Sep 11 2014 toddrme2178@gmail.com
- Update to version 1.1.2
  - This is a maintenance release with no changes to the actual
    library source code.
  * Stop distributing benchmark data files that have unclear
    or unsuitable licensing.
  * Add support for padding chunks in the framing format.
* Wed Nov 13 2013 p.drouand@gmail.com
- Update to version 1.1.1
  * Add support for uncompressing to iovecs (scatter I/O).
  * Speed up decompression by ~2%%; much more so (~13-20%%) on
    a few benchmarks on given compilers and CPUs.
  * Fix a few issues with MSVC compilation.
  * Support truncated test data in the benchmark.
- Adapt patch to upstream changes
  * snappy-random-return.patch > snappy-1.1.1-random-return.patch
* Thu Aug 22 2013 cdenicolo@suse.com
- license update: BSD-3-Clause
  correct license is BSD-3-Clause.
* Thu Aug 15 2013 mvyskocil@suse.com
- Update to 1.1.0 (FATE#315420)
  * Snappy now uses 64 kB block size instead of 32 kB. On average,
    this means it compresses about 3%% denser (more so for some
    inputs), at the same or better speeds.
  * libsnappy no longer depends on iostream.
  * Some small performance improvements in compression on x86
    (0.5–1%%).
  * Various portability fixes for ARM-based platforms, for MSVC,
    and for GNU/Hurd.
- refresh and rename random-return.patch
  * snappy-random-return.patch
- reformat spec file
- build with NDEBUG to speedup a library
- install COPYING alongside so file
* Fri Nov 23 2012 mrueckert@suse.de
- update to 1.0.5
  * More speed improvements. Exactly how big will depend on
    the architecture:
  - 3–10%% faster decompression for the base case (x86-64).
  - ARMv7 and higher can now use unaligned accesses,
    and will see about 30%% faster decompression and
    20–40%% faster compression.
  - 32-bit platforms (ARM and 32-bit x86) will see 2–5%%
    faster compression.
    These are all cumulative (e.g., ARM gets all three speedups).
  * Fixed an issue where the unit test would crash on system
    with less than 256 MB address space available,
    e.g. some embedded platforms.
  * Added a framing format description, for use over e.g. HTTP,
    or for a command-line compressor. We do not have any
    implementations of this at the current point, but there seems
    to be enough of a general interest in the topic.
    Also make the format description slightly clearer.
  * Remove some compile-time warnings in -Wall
    (mostly signed/unsigned comparisons), for easier embedding
    into projects that use -Wall -Werror.
* Wed Feb  8 2012 mrueckert@suse.de
- initial package (v1.0.4)
